@@ -11,5 +11,5 @@ class StaticFile:
     def __init__(self, directory):
         self.directory = directory
     
-    async def __call__(self, path: str):
+    async def __call__(self, request, path: str):
         return FileResponse(path, media_type="text/css")
\ No newline at end of file
